module.exports = {
	description: 'getInterop with interop: false',
	options: {
		output: { name: 'foo', interop: false },
	}
};
